import { devServer as devServer$1 } from '@cypress/webpack-dev-server';
import { AngularWebpackPlugin } from '@ngtools/webpack';
import * as fs from 'fs';
import linkerPlugin from '@angular/compiler-cli/linker/babel';

const generateTsConfigContent = (specPattern) => `
{
  "extends": "./tsconfig.json",
  "compilerOptions": {
    "outDir": "./out-tsc/cy",
    "types": ["cypress"],
    "allowSyntheticDefaultImports": true
  },
  "include": ["src/**/*.d.ts", "${specPattern}"]
}
`;
const generateTsConfig = (specPattern) => {
    const tsconfigContent = generateTsConfigContent(specPattern);
    fs.writeFileSync('tsconfig.cy.json', tsconfigContent);
};
const webpackConfig = {
    mode: 'development',
    module: {
        rules: [
            {
                test: /\.[jt]sx?$/,
                loader: '@ngtools/webpack',
            },
            {
                test: /(\.scss|\.sass)$/,
                use: ['raw-loader', 'sass-loader'],
            },
            {
                test: /\.m?js$/,
                use: {
                    loader: 'babel-loader',
                    options: {
                        plugins: [linkerPlugin],
                        compact: false,
                        cacheDirectory: true
                    }
                }
            }
        ],
    },
    resolve: {
        extensions: ['.ts', '.js'],
    },
    plugins: [
        new AngularWebpackPlugin({
            tsconfig: './tsconfig.cy.json'
        }),
    ],
};
function generateWebpackConfig(specPattern) {
    generateTsConfig(specPattern);
    return webpackConfig;
}
;

function devServer(cypressDevServerConfig) {
    const { config } = cypressDevServerConfig;
    const { specPattern } = config;
    const webpackConfig = generateWebpackConfig(specPattern);
    return devServer$1(cypressDevServerConfig, { webpackConfig });
}

/*
 * Public API Surface of angular-dev-server
 */

/**
 * Generated bundle index. Do not edit.
 */

export { devServer };
//# sourceMappingURL=cypress-angular-dev-server.js.map
